@@ -1,8 +1,8 @@
 #!/usr/bin/python3
 import time
 import sys
+import os
 from pkg_resources import Requirement, resource_filename
-import pynhost
 from pynhost import utilities
 from pynhost import grammarhandler
 
@@ -33,7 +33,7 @@ def main():
         last_action = []
         add_space = False
         while True:
-            lines = utilities.get_buffer_lines(CONFIG_PATH)
+            lines = utilities.get_buffer_lines(os.path.join(shared_dir, 'buffer.txt'))
             time.sleep(.2)
             for line in lines:
                 result = {'remaining words': line.split(' ')}
